@@ -485,7 +485,7 @@ namespace LinBox
 
 			_fftsize=0;
 			//check if field is based on fft prime
-			size_t p = _p;
+			uint64_t p = _p;
 			if (p&1){
 				p-=1;
 				do { p=p>>1; _fftsize++;} while(!(p&0x0001));
@@ -519,22 +519,18 @@ namespace LinBox
 				while ( k ) {k>>=1; ++ln;}
 
 				// taking primes greater than current prime
-				size_t bit = std::max((53-ln)>>1, _p.bitsize());
+				uint64_t bit = std::max((53-ln)>>1, _p.bitsize());
 
 				// get number of necessary primes
-				integer ibound = uint64_t(n) * _p * _p * std::max(b.size(), c.size());
-				integer primesprod;
-				size_t nbrprimes=1;
-				RandomFFTPrime fftprime((size_t)bit, FFT_PRIME_SEED);
-				std::vector<integer> lprimes(10); lprimes.resize(nbrprimes);
-				lprimes[0] = fftprime.generatePrime();
-				primesprod = lprimes[0];
-				while (primesprod < ibound) {
-					++nbrprimes;
-					lprimes.resize(nbrprimes);
-					do {lprimes[nbrprimes-1] = fftprime.generatePrime();} while (primesprod % lprimes[nbrprimes-1] == 0);
-					primesprod *= lprimes[nbrprimes-1];
-				}
+				integer ibound = uint64_t(n) * _p * _p * uint64_t(std::max(b.size(), c.size()));
+				std::vector<integer> lprimes;
+				RandomFFTPrime::seeding (FFT_PRIME_SEED);
+				if (!RandomFFTPrime::generatePrimes (lprimes, bit, ibound))
+					throw LinboxError ("RandomFFTPrime::generatePrime failed");
+				size_t nbrprimes = lprimes.size();
+				integer primesprod = 1;
+				for (auto &p: lprimes)
+					primesprod *= p;
 #ifdef FFT_TIMING
 				std::cout<<"num of primes "<<nbrprimes<< std::endl;
 #endif
@@ -635,23 +631,18 @@ namespace LinBox
 				}
 
 				// taking primes greater than current prime
-				size_t bit = std::max((53-ln)>>1, _p.bitsize());
+				uint64_t bit = std::max((53-ln)>>1, _p.bitsize());
 
 				// get number of necessary primes
-				integer ibound = uint64_t(n) * _p * _p * std::max(b.size(), c.size());
-				integer primesprod;
-				size_t nbrprimes=1;
-				RandomFFTPrime fftprime(bit, FFT_PRIME_SEED);
-				std::vector<integer> lprimes(10); lprimes.resize(nbrprimes);
-				lprimes[0] = fftprime.generatePrime();
-				primesprod = lprimes[0];
-				while (primesprod < ibound) {
-					++nbrprimes;
-					lprimes.resize(nbrprimes);
-					do {lprimes[nbrprimes-1] = fftprime.generatePrime();} while (primesprod % lprimes[nbrprimes-1] == 0);
-					primesprod *= lprimes[nbrprimes-1];
-				}
-
+				integer ibound = uint64_t(n) * _p * _p * uint64_t(std::max(b.size(), c.size()));
+				std::vector<integer> lprimes;
+				RandomFFTPrime::seeding (FFT_PRIME_SEED);
+				if (!RandomFFTPrime::generatePrimes (lprimes, bit, ibound))
+					throw LinboxError ("RandomFFTPrime::generatePrime failed");
+				size_t nbrprimes = lprimes.size();
+				integer primesprod = 1;
+				for (auto &p: lprimes)
+					primesprod *= p;
 #ifdef FFT_TIMING
 				std::cout<<"num of primes "<<nbrprimes<<"\n";
 #endif
@@ -777,17 +768,14 @@ namespace LinBox
 
 			// get number of necessary primes
 			integer ibound = n * _p * _p * std::max(b.size(), c.size());
-			integer primesprod=1; size_t nbrprimes=1;
-			RandomFFTPrime fftprime(bit, FFT_PRIME_SEED);
-			std::vector<integer> lprimes(10); lprimes.resize(nbrprimes);
-			lprimes[0] = fftprime.generatePrime();
-			primesprod = lprimes[0];
-			while (primesprod < ibound) {
-				++nbrprimes;
-				lprimes.resize(nbrprimes);
-				do {lprimes[nbrprimes-1] = fftprime.generatePrime();} while (primesprod % lprimes[nbrprimes-1] == 0);
-				primesprod *= lprimes[nbrprimes-1];
-			}
+			std::vector<integer> lprimes;
+			RandomFFTPrime::seeding (FFT_PRIME_SEED);
+			if (!RandomFFTPrime::generatePrimes (lprimes, bit, ibound))
+				throw LinboxError ("RandomFFTPrime::generatePrime failed");
+			size_t nbrprimes = lprimes.size();
+			integer primesprod = 1;
+			for (auto &p: lprimes)
+				primesprod *= p;
 #ifdef FFT_TIMING
 			std::cout<<"num of primes "<<nbrprimes<<"\n";
 #endif
@@ -894,18 +882,14 @@ namespace LinBox
 
 				// get number of necessary primes
 				integer ibound = n * _p * _p * std::max(b.size(), c.size());
-				integer primesprod=1; size_t nbrprimes=1;
-				RandomFFTPrime fftprime(bit, FFT_PRIME_SEED);
-				std::vector<integer> lprimes(10); lprimes.resize(nbrprimes);
-				lprimes[0] = fftprime.generatePrime();
-				primesprod = lprimes[0];
-				while (primesprod < ibound) {
-					++nbrprimes;
-					lprimes.resize(nbrprimes);
-					do {lprimes[nbrprimes-1] = fftprime.generatePrime();} while (primesprod % lprimes[nbrprimes-1] == 0);
-					primesprod *= lprimes[nbrprimes-1];
-				}
-
+				std::vector<integer> lprimes;
+				RandomFFTPrime::seeding (FFT_PRIME_SEED);
+				if (!RandomFFTPrime::generatePrimes (lprimes, bit, ibound))
+					throw LinboxError ("RandomFFTPrime::generatePrime failed");
+				size_t nbrprimes = lprimes.size();
+				integer primesprod = 1;
+				for (auto &p: lprimes)
+					primesprod *= p;
 #ifdef FFT_TIMING
 				std::cout<<"num of primes "<<nbrprimes<<"\n";
 #endif
@@ -1002,7 +986,7 @@ namespace LinBox
 			// find a pseudo primitive element of the multiplicative group _p -1
 			long m = _pl - 1;
 			long k = 0;
-			srand((unsigned int)time(NULL));
+			srand(static_cast<unsigned int>(std::time(nullptr)));
 			while ((m & 1) == 0) {
 				m = m >> 1;
 				k++;
@@ -1044,7 +1028,7 @@ namespace LinBox
 
 			size_t deg     = b.size()+c.size()-1;
 			size_t lpts = 0;
-			size_t pts =1; while (pts < deg) { pts= pts<<1; ++lpts; }
+			uint64_t pts =1; while (pts < deg) { pts= pts<<1; ++lpts; }
 
 #ifdef FFT_TIMING
 			std::cout<<"FFT: points "<<pts<<"\n";
@@ -1065,7 +1049,7 @@ namespace LinBox
 				// find a pseudo primitive element of the multiplicative group _p-1
 				long mm = _pl - 1;
 				long kk = 0;
-				srand((unsigned int)time(NULL));
+				srand(static_cast<unsigned int>(std::time(nullptr)));
 				while ((mm & 1) == 0) {
 					mm = mm >> 1;
 					kk++;
@@ -1266,7 +1250,7 @@ namespace LinBox
 
 			size_t deg  = c.size()+1;
 			size_t lpts = 0;
-			size_t pts =1; while (pts < deg) { pts= pts<<1; ++lpts; }
+			uint64_t pts =1; while (pts < deg) { pts= pts<<1; ++lpts; }
 
 			if (_p%pts != 1) {
 				std::cout<<"Error the prime is not a FFTPrime or it has too small power of 2\n";
@@ -1287,7 +1271,7 @@ namespace LinBox
 				// find a pseudo primitive element of the multiplicative group _p-1
 				long mm = _pl - 1;
 				long kk = 0;
-				srand((unsigned int)time(NULL));
+				srand(static_cast<unsigned int>(std::time(nullptr)));
 				while ((mm & 1) == 0) {
 					mm = mm >> 1;
 					kk++;
@@ -1446,7 +1430,7 @@ namespace LinBox
 				// find a pseudo primitive element of the multiplicative group _p-1
 				long mm = _pl - 1;
 				long kk = 0;
-				srand((unsigned int)time(NULL));
+				srand(static_cast<unsigned int>(std::time(nullptr)));
 				while ((mm & 1) == 0) {
 					mm = mm >> 1;
 					kk++;
@@ -1813,11 +1797,10 @@ namespace LinBox
 
 #endif //__LINBOX_matpoly_mult_H
 
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
